| Title: | Estimating Reservoir Evaporation via Aerodynamic Approach |
|---|---|
| Description: | Developed as an 'R' alternative to the 'AeroEvap' model developed by the Desert Research Institute (DRI) in 'python' <https://github.com/WSWUP/AeroEvap/blob/master/README.rst> which estimates open water evaporation using the aerodynamic mass transfer approach. |
| Authors: | Elise Madonna [aut], Kathleen Holman [aut], Ally Fitts [aut, cre], John Volk [aut], Chris Pearson [aut] |
| Maintainer: | Ally Fitts <[email protected]> |
| License: | CC0 |
| Version: | 0.1.6 |
| Built: | 2026-06-07 06:16:16 UTC |
| Source: | https://github.com/cran/AeroEvapR |
This package uses the aerodynamic mass transfer approach on variables given in the input file to estimate open water evaporation. The output includes calculated evaporation parameters as well as the input values.
aero_calc(df, sensor_height, timestep, out_file_format,out_file_name, verbose)aero_calc(df, sensor_height, timestep, out_file_format,out_file_name, verbose)
df |
Dataframe containing input data. Must include all data components ('T_skin', 'WS', 'P', 'T_air', 'RH', 'date'). Ensure date is formatted as a date object before reading into function. |
sensor_height |
Sensor height (m) |
timestep |
Measurement frequency (s). For example, hourly data would be timestep = 3600 |
out_file_format |
Format for output file |
out_file_name |
Name for saved file |
verbose |
Logical indicator to hide output messages (FALSE will hide messages) |
Returns a list with calculated values for evaporation (mm/timestep), bulk transfer coefficient, vapor pressure deficit (kPa), and most stability value
SH |
Sensor height (m) |
dt |
Timestep |
E |
Evaporation (mm/timestep) |
Ce |
bulk transfer coefficent (unitless) |
VPD |
Vapor pressure deficit (kPA) |
stability |
Monin-Obhukov Similarity Theory stability parameter (z/L) |
This package was developed based on AeroEvap, a Python implementation of the aerodynamic mass-transfer approach for open-water evaporation. See AeroEvap on GitHub.
Ally Fitts ([email protected])\ Elise Madonna\ Kathleen Holman\ John Volk \ Chris Pearson\
AeroEvap (Python version): https://github.com/WSWUP/AeroEvap/tree/master
old_par <- par(no.readonly = TRUE) df <- data.frame( date = seq(as.POSIXct("2020-01-01"), by = 3600, length.out = 5), T_skin = c(20, 21, 22, 21, 20), WS = c(3, 3.5, 4, 3.8, 3.2), P = rep(101.3, 5), T_air = c(18, 18.5, 19, 18.8, 18.2), RH = c(50, 52, 51, 49, 50) ) # Run aero_calc with sample inputs result <- aero_calc(df, sensor_height = 2, timestep = 3600, out_file_format = "none", out_file_name = NULL, verbose = TRUE) # View results print(result) # Reset graphical parameters par(old_par)old_par <- par(no.readonly = TRUE) df <- data.frame( date = seq(as.POSIXct("2020-01-01"), by = 3600, length.out = 5), T_skin = c(20, 21, 22, 21, 20), WS = c(3, 3.5, 4, 3.8, 3.2), P = rep(101.3, 5), T_air = c(18, 18.5, 19, 18.8, 18.2), RH = c(50, 52, 51, 49, 50) ) # Run aero_calc with sample inputs result <- aero_calc(df, sensor_height = 2, timestep = 3600, out_file_format = "none", out_file_name = NULL, verbose = TRUE) # View results print(result) # Reset graphical parameters par(old_par)